@@ -1,5 +1,4 @@
 import unittest
-from StringIO import StringIO
 import re
 import sys
 
@@ -305,11 +304,11 @@ _FILLMELDFORM_HTML = """\
 
 class MeldAPITests(unittest.TestCase):
     def _makeElement(self, string):
-        from meld3 import parse_xmlstring
+        from . import parse_xmlstring
         return parse_xmlstring(string)
 
     def _makeElementFromHTML(self, string):
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         return parse_htmlstring(string)
 
     def test_findmeld(self):
@@ -417,14 +416,14 @@ class MeldAPITests(unittest.TestCase):
 
         clone = root.clone()
         unfilled = clone.fillmeldhtmlform(**data[2])
-        self.assertEqual(unfilled, ['notthere', 'suffix'])
+        self.assertEqual(sorted(unfilled), ['notthere', 'suffix'])
         self.assertEqual(clone.findmeld('honorific').text, None)
         favoritecolor = clone.findmeld('favorite_color:inputgroup')
         self.assertEqual(favoritecolor[2].attrib['checked'], 'checked')
         self.assertEqual(favoritecolor[1].attrib.get('checked'), None)
 
     def test_replace_removes_all_elements(self):
-        from meld3 import Replace
+        from . import Replace
         root = self._makeElement(_SIMPLE_XML)
         L = root.findmeld('list')
         L.replace('this is a textual replacement')
@@ -433,7 +432,7 @@ class MeldAPITests(unittest.TestCase):
         self.assertEqual(len(root.getchildren()), 1)
 
     def test_replace_replaces_the_right_element(self):
-        from meld3 import Replace
+        from . import Replace
         root = self._makeElement(_SIMPLE_XML)
         D = root.findmeld('description')
         D.replace('this is a textual replacement')
@@ -454,7 +453,7 @@ class MeldAPITests(unittest.TestCase):
         self.assertEqual(D.structure, False)
 
     def test_content(self):
-        from meld3 import Replace
+        from . import Replace
         root = self._makeElement(_SIMPLE_XML)
         D = root.findmeld('description')
         D.content('this is a textual replacement')
@@ -478,7 +477,7 @@ class MeldAPITests(unittest.TestCase):
         self.assertEqual(T.structure, False)
 
     def test_attributes(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         root = self._makeElement(_COMPLEX_XHTML)
         D = root.findmeld('form1')
         D.attributes(foo='bar', baz='1', g='2', action='#')
@@ -487,13 +486,24 @@ class MeldAPITests(unittest.TestCase):
             'method':'POST', 'action':'#',
             _MELD_ID: 'form1'})
 
+    def test_attributes_unicode(self):
+        from . import _MELD_ID
+        from ._compat import _u
+        root = self._makeElement(_COMPLEX_XHTML)
+        D = root.findmeld('form1')
+        D.attributes(foo=_u('bar'), action=_u('#'))
+        self.assertEqual(D.attrib, {
+            'foo':_u('bar'),
+            'method':'POST', 'action': _u('#'),
+            _MELD_ID: 'form1'})
+
     def test_attributes_nonstringtype_raises(self):
         root = self._makeElement('<root></root>')
         self.assertRaises(ValueError, root.attributes, foo=1)
 
 class MeldElementInterfaceTests(unittest.TestCase):
     def _getTargetClass(self):
-        from meld3 import _MeldElementInterface
+        from . import _MeldElementInterface
         return _MeldElementInterface
 
     def _makeOne(self, *arg, **kw):
@@ -502,7 +512,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
 
     def test_repeat(self):
         root = self._makeOne('root', {})
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         item = self._makeOne('item', {_MELD_ID:'item'})
         record = self._makeOne('record', {_MELD_ID:'record'})
         name = self._makeOne('name', {_MELD_ID:'name'})
@@ -547,7 +557,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
         self.assertEqual(replacenode.parent, el)
         self.assertEqual(replacenode.text, 'hello')
         self.assertEqual(replacenode.structure, False)
-        from meld3 import Replace
+        from . import Replace
         self.assertEqual(replacenode.tag, Replace)
 
     def test_content_simple_structure(self):
@@ -558,23 +568,23 @@ class MeldElementInterfaceTests(unittest.TestCase):
         self.assertEqual(replacenode.parent, el)
         self.assertEqual(replacenode.text, 'hello')
         self.assertEqual(replacenode.structure, True)
-        from meld3 import Replace
+        from . import Replace
         self.assertEqual(replacenode.tag, Replace)
 
     def test_findmeld_simple(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         el = self._makeOne('div', {_MELD_ID:'thediv'})
         self.assertEqual(el.findmeld('thediv'), el)
 
     def test_findmeld_simple_oneleveldown(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         el = self._makeOne('div', {_MELD_ID:'thediv'})
         span = self._makeOne('span', {_MELD_ID:'thespan'})
         el.append(span)
         self.assertEqual(el.findmeld('thespan'), span)
 
     def test_findmeld_simple_twolevelsdown(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         el = self._makeOne('div', {_MELD_ID:'thediv'})
         span = self._makeOne('span', {_MELD_ID:'thespan'})
         a = self._makeOne('a', {_MELD_ID:'thea'})
@@ -691,10 +701,10 @@ class MeldElementInterfaceTests(unittest.TestCase):
         self.assertEqual(div[0][0][0].text, div2[0][0][0].text)
         self.assertEqual(div[0][0][0].tail, div2[0][0][0].tail)
 
-        self.failIfEqual(id(div), id(div2))
-        self.failIfEqual(id(div[0]), id(div2[0]))
-        self.failIfEqual(id(div[0][0]), id(div2[0][0]))
-        self.failIfEqual(id(div[0][0][0]), id(div2[0][0][0]))
+        self.assertNotEqual(id(div), id(div2))
+        self.assertNotEqual(id(div[0]), id(div2[0]))
+        self.assertNotEqual(id(div[0][0]), id(div2[0][0]))
+        self.assertNotEqual(id(div[0][0][0]), id(div2[0][0][0]))
 
     def test_deparent_noparent(self):
         div = self._makeOne('div', {})
@@ -748,7 +758,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
         self.assertEqual(len(parent._children), 0)
 
     def test_lineage(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         div1 = self._makeOne('div', {_MELD_ID:'div1'})
         span1 = self._makeOne('span', {_MELD_ID:'span1'})
         span2 = self._makeOne('span', {_MELD_ID:'span2'})
@@ -790,6 +800,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
 
 
     def test_shortrepr(self):
+        from ._compat import _b
         div = self._makeOne('div', {'id':'div1'})
         span = self._makeOne('span', {})
         span2 = self._makeOne('span', {'id':'2'})
@@ -802,18 +813,29 @@ class MeldElementInterfaceTests(unittest.TestCase):
         span.append(span2)
         div.append(div2)
         r = div.shortrepr()
-        self.assertEqual(r, '<div id="div1"><span><span id="2"></span></span><div2 id="div2"></div2></div>')
+        self.assertEqual(r,
+            _b('<div id="div1"><span><span id="2"></span></span>'
+               '<div2 id="div2"></div2></div>'))
 
     def test_shortrepr2(self):
-        from meld3 import parse_xmlstring
+        from . import parse_xmlstring
+        from ._compat import _b
         root = parse_xmlstring(_COMPLEX_XHTML)
         r = root.shortrepr()
-        self.assertEqual(r, '<html>\n  <head>\n    <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type">\n     [...]\n</head>\n  <!--  a comment  -->\n   [...]\n</html>')
+        self.assertEqual(r,
+            _b('<html>\n'
+               '  <head>\n'
+               '    <meta content="text/html; charset=ISO-8859-1" '
+                         'http-equiv="content-type">\n'
+               '     [...]\n</head>\n'
+               '  <!--  a comment  -->\n'
+               '   [...]\n'
+               '</html>'))
 
 
     def test_diffmeld1(self):
-        from meld3 import parse_xmlstring
-        from meld3 import _MELD_ID
+        from . import parse_xmlstring
+        from . import _MELD_ID
         root = parse_xmlstring(_COMPLEX_XHTML)
         clone = root.clone()
         div = self._makeOne('div', {_MELD_ID:'newdiv'})
@@ -862,7 +884,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
           <b meld:id="b"></b>
         </root>
         """
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         source_root = parse_htmlstring(source)
         target_root = parse_htmlstring(target)
         changes = source_root.diffmeld(target_root)
@@ -918,7 +940,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
           </d>
         </root>
         """
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         source_root = parse_htmlstring(source)
         target_root = parse_htmlstring(target)
         changes = source_root.diffmeld(target_root)
@@ -978,7 +1000,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
           </p>
         </root>
         """
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         source_root = parse_htmlstring(source)
         target_root = parse_htmlstring(target)
         changes = source_root.diffmeld(target_root)
@@ -1042,7 +1064,7 @@ class MeldElementInterfaceTests(unittest.TestCase):
           </z>
         </root>
         """
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         source_root = parse_htmlstring(source)
         target_root = parse_htmlstring(target)
         changes = source_root.diffmeld(target_root)
@@ -1077,17 +1099,17 @@ class MeldElementInterfaceTests(unittest.TestCase):
 
 class ParserTests(unittest.TestCase):
     def _parse(self, *args):
-        from meld3 import parse_xmlstring
+        from . import parse_xmlstring
         root = parse_xmlstring(*args)
         return root
 
     def _parse_html(self, *args):
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         root = parse_htmlstring(*args)
         return root
 
     def test_parse_simple_xml(self):
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         root = self._parse(_SIMPLE_XML)
         self.assertEqual(root.tag, 'root')
         self.assertEqual(root.parent, None)
@@ -1110,7 +1132,7 @@ class ParserTests(unittest.TestCase):
 
     def test_parse_simple_xhtml(self):
         xhtml_ns = '{http://www.w3.org/1999/xhtml}%s'
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
 
         root = self._parse(_SIMPLE_XHTML)
         self.assertEqual(root.tag, xhtml_ns % 'html')
@@ -1123,7 +1145,7 @@ class ParserTests(unittest.TestCase):
 
     def test_parse_complex_xhtml(self):
         xhtml_ns = '{http://www.w3.org/1999/xhtml}%s'
-        from meld3 import _MELD_ID
+        from . import _MELD_ID
         root = self._parse(_COMPLEX_XHTML)
         self.assertEqual(root.tag, xhtml_ns % 'html')
         self.assertEqual(root.attrib, {})
@@ -1196,8 +1218,8 @@ class ParserTests(unittest.TestCase):
         self.assertEqual(td2.parent, tr)
 
     def test_nvu_html(self):
-        from meld3 import _MELD_ID
-        from meld3 import Comment
+        from . import _MELD_ID
+        from . import Comment
         root = self._parse_html(_NVU_HTML)
         self.assertEqual(root.tag, 'html')
         self.assertEqual(root.attrib, {})
@@ -1258,52 +1280,56 @@ class ParserTests(unittest.TestCase):
 class UtilTests(unittest.TestCase):
 
     def test_insert_xhtml_doctype(self):
-        from meld3 import insert_doctype
+        from . import insert_doctype
         orig = '<root></root>'
         actual = insert_doctype(orig)
         expected = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><root></root>'
         self.assertEqual(actual, expected)
 
     def test_insert_doctype_after_xmldecl(self):
-        from meld3 import insert_doctype
+        from . import insert_doctype
         orig = '<?xml version="1.0" encoding="latin-1"?><root></root>'
         actual = insert_doctype(orig)
         expected = '<?xml version="1.0" encoding="latin-1"?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><root></root>'
         self.assertEqual(actual, expected)
 
     def test_insert_meld_ns_decl(self):
-        from meld3 import insert_meld_ns_decl
+        from . import insert_meld_ns_decl
         orig = '<?xml version="1.0" encoding="latin-1"?><root></root>'
         actual = insert_meld_ns_decl(orig)
         expected = '<?xml version="1.0" encoding="latin-1"?><root xmlns:meld="http://www.plope.com/software/meld3"></root>'
         self.assertEqual(actual, expected)
 
     def test_prefeed_preserves_existing_meld_ns(self):
-        from meld3 import prefeed
+        from . import prefeed
         orig = '<?xml version="1.0" encoding="latin-1"?><root xmlns:meld="#"></root>'
         actual = prefeed(orig)
         expected = '<?xml version="1.0" encoding="latin-1"?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><root xmlns:meld="#"></root>'
         self.assertEqual(actual, expected)
 
     def test_prefeed_preserves_existing_doctype(self):
-        from meld3 import prefeed
+        from . import prefeed
         orig = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"><root xmlns:meld="http://www.plope.com/software/meld3"></root>'
         actual = prefeed(orig)
         self.assertEqual(actual, orig)
 
 class WriterTests(unittest.TestCase):
     def _parse(self, xml):
-        from meld3 import parse_xmlstring
+        from . import parse_xmlstring
         root = parse_xmlstring(xml)
         return root
 
     def _parse_html(self, xml):
-        from meld3 import parse_htmlstring
+        from . import parse_htmlstring
         root = parse_htmlstring(xml)
         return root
 
     def _write(self, fn, **kw):
-        out = StringIO()
+        try:
+            from io import BytesIO
+        except: # python 2.5
+            from StringIO import StringIO as BytesIO
+        out = BytesIO()
         fn(out, **kw)
         out.seek(0)
         actual = out.read()
@@ -1319,13 +1345,15 @@ class WriterTests(unittest.TestCase):
         return self._write(node.write_xhtml, **kw)
 
     def assertNormalizedXMLEqual(self, a, b):
-        a = normalize_xml(a)
-        b = normalize_xml(b)
+        from ._compat import _u
+        a = normalize_xml(_u(a))
+        b = normalize_xml(_u(b))
         self.assertEqual(a, b)
 
     def assertNormalizedHTMLEqual(self, a, b):
-        a = normalize_html(a)
-        b = normalize_html(b)
+        from ._compat import _u
+        a = normalize_xml(_u(a))
+        b = normalize_xml(_u(b))
         self.assertEqual(a, b)
 
     def test_write_simple_xml(self):
@@ -1459,6 +1487,7 @@ class WriterTests(unittest.TestCase):
         self.assertNormalizedXMLEqual(actual, expected)
 
     def test_write_emptytags_html(self):
+        from ._compat import _u
         root = self._parse(_EMPTYTAGS_HTML)
         actual = self._write_html(root)
         expected = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
@@ -1468,7 +1497,7 @@ class WriterTests(unittest.TestCase):
     <link><meta><param>
   </body>
 </html>"""
-        self.assertEqual(actual, expected)
+        self.assertEqual(_u(actual), expected)
 
     def test_write_booleanattrs_xhtml_as_html(self):
         root = self._parse(_BOOLEANATTRS_XHTML)
@@ -1513,7 +1542,6 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xml_override_encoding(self):
         root = self._parse(_SIMPLE_XML)
-        from meld3 import doctype
         actual = self._write_xml(root, encoding="latin-1")
         expected = """<?xml version="1.0" encoding="latin-1"?><root>
   <list>
@@ -1528,7 +1556,6 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xml_as_fragment(self):
         root = self._parse(_SIMPLE_XML)
-        from meld3 import doctype
         actual = self._write_xml(root, fragment=True)
         expected = """<root>
   <list>
@@ -1542,7 +1569,7 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xml_with_doctype(self):
         root = self._parse(_SIMPLE_XML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xml(root, doctype=doctype.xhtml)
         expected = """<?xml version="1.0"?>
         <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><root>
@@ -1557,7 +1584,7 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xml_doctype_nodeclaration(self):
         root = self._parse(_SIMPLE_XML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xml(root, declaration=False,
                                  doctype=doctype.xhtml)
         expected = """<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><root>
@@ -1572,7 +1599,7 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xml_fragment_kills_doctype_and_declaration(self):
         root = self._parse(_SIMPLE_XML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xml(root, declaration=True,
                                  doctype=doctype.xhtml, fragment=True)
         expected = """<root>
@@ -1587,28 +1614,26 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xhtml_override_encoding(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
         actual = self._write_xhtml(root, encoding="latin-1", declaration=True)
         expected = """<?xml version="1.0" encoding="latin-1"?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html><body>Hello!</body></html>"""
         self.assertNormalizedXMLEqual(actual, expected)
 
     def test_write_simple_xhtml_as_fragment(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
         actual = self._write_xhtml(root, fragment=True)
         expected = """<html><body>Hello!</body></html>"""
         self.assertNormalizedXMLEqual(actual, expected)
 
     def test_write_simple_xhtml_with_doctype(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xhtml(root, doctype=doctype.xhtml)
         expected = """<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html><body>Hello!</body></html>"""
         self.assertNormalizedXMLEqual(actual, expected)
 
     def test_write_simple_xhtml_doctype_nodeclaration(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xhtml(root, declaration=False,
                                  doctype=doctype.xhtml)
         expected = """<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html><body>Hello!</body></html>"""
@@ -1616,7 +1641,7 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xhtml_fragment_kills_doctype_and_declaration(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_xhtml(root, declaration=True,
                                  doctype=doctype.xhtml, fragment=True)
         expected = """<html><body>Hello!</body></html>"""
@@ -1624,7 +1649,6 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xhtml_as_html_fragment(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
         actual = self._write_html(root, fragment=True)
         expected = """<html><body>Hello!</body></html>"""
         self.assertNormalizedXMLEqual(actual, expected)
@@ -1639,7 +1663,7 @@ class WriterTests(unittest.TestCase):
 
     def test_write_simple_xhtml_as_html_new_doctype(self):
         root = self._parse(_SIMPLE_XHTML)
-        from meld3 import doctype
+        from . import doctype
         actual = self._write_html(root, doctype=doctype.html_strict)
         expected = """
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
@@ -1742,24 +1766,39 @@ class WriterTests(unittest.TestCase):
         self.assertNormalizedXMLEqual(actual, expected)
 
     def test_escape_cdata(self):
-        a = '< > &lt;&amp; &&apos; && &foo "" http://www.plope.com?foo=bar&bang=baz &#123;'
-        from meld3 import _escape_cdata
-        self.assertEqual('&lt; > &lt;&amp; &amp;&apos; &amp;&amp; &amp;foo "" http://www.plope.com?foo=bar&amp;bang=baz &#123;', _escape_cdata(a))
+        from ._compat import _b
+        from . import _escape_cdata
+        a = ('< > &lt;&amp; &&apos; && &foo "" '
+             'http://www.plope.com?foo=bar&bang=baz &#123;')
+        self.assertEqual(
+            _b('&lt; > &lt;&amp; &amp;&apos; &amp;&amp; &amp;foo "" '
+               'http://www.plope.com?foo=bar&amp;bang=baz &#123;'),
+            _escape_cdata(a))
 
     def test_escape_cdata_unicodeerror(self):
-        a = eval(r'u"\u0080"')
-        from meld3 import _escape_cdata
-        self.assertEqual('&#128;', _escape_cdata(a, 'ascii'))
+        from . import _escape_cdata
+        from ._compat import _b
+        from ._compat import _u
+        a = _u(_b('\x80'))
+        self.assertEqual(_b('&#128;'), _escape_cdata(a, 'ascii'))
 
     def test_escape_attrib(self):
-        a = '< > &lt;&amp; &&apos; && &foo "" http://www.plope.com?foo=bar&bang=baz &#123;'
-        from meld3 import _escape_attrib
-        self.assertEqual('&lt; > &lt;&amp; &amp;&apos; &amp;&amp; &amp;foo &quot;&quot; http://www.plope.com?foo=bar&amp;bang=baz &#123;', _escape_attrib(a))
+        from . import _escape_attrib
+        from ._compat import _b
+        a = ('< > &lt;&amp; &&apos; && &foo "" '
+             'http://www.plope.com?foo=bar&bang=baz &#123;')
+        self.assertEqual(
+            _b('&lt; > &lt;&amp; &amp;&apos; '
+               '&amp;&amp; &amp;foo &quot;&quot; '
+               'http://www.plope.com?foo=bar&amp;bang=baz &#123;'),
+            _escape_attrib(a, None))
 
     def test_escape_attrib_unicodeerror(self):
-        a = eval(r'u"\u0080"')
-        from meld3 import _escape_attrib
-        self.assertEqual('&#128;', _escape_attrib(a, 'ascii'))
+        from . import _escape_attrib
+        from ._compat import _b
+        from ._compat import _u
+        a = _u(_b('\x80'))
+        self.assertEqual(_b('&#128;'), _escape_attrib(a, 'ascii'))
 
 def normalize_html(s):
     s = re.sub(r"[ \t]+", " ", s)
@@ -1773,17 +1812,10 @@ def normalize_xml(s):
     return s
 
 def test_suite():
-    suite = unittest.TestSuite()
-    suite.addTest( unittest.makeSuite( MeldAPITests ) )
-    suite.addTest( unittest.makeSuite( MeldElementInterfaceTests ) )
-    suite.addTest( unittest.makeSuite( ParserTests ) )
-    suite.addTest( unittest.makeSuite( WriterTests) )
-    suite.addTest( unittest.makeSuite( UtilTests) )
-    return suite
+    return unittest.findTestCases(sys.modules[__name__])
 
 def main():
     unittest.main(defaultTest='test_suite')
 
 if __name__ == '__main__':
     main()
-
